@@ -70,6 +70,11 @@ if os.path.exists(tmp_dir + "/Available.prv"):
     os.rename(tmp_dir + "/Available.prv", init_dir + "/Available.prv")
 if os.path.exists(tmp_dir + "/Installed"): 
     os.rename(tmp_dir + "/Installed", init_dir + "/Installed")
+
+# 100104 Remove any old tmp files. Bug#563573
+
+os.system("rm -f " + init_dir + "/tmp*")
+
 #
 # TODO 23 Aug 2003
 #
