@@ -105,9 +105,18 @@ def get_available(command="dumpavail"):
     # a chance to understand the new APT package for Python. So put
     # the apt-cache dump into a file and then use that file here.
 
+    # 090501 Note that using "apt-cache dumpavail" misses packages
+    # that are installed but are no longer available. So why not
+    # append /var/lib/dpkg/status to be more comprehensive? Would
+    # repeats be an issue? Closes Bug#432266
+
     tmpcache = tempfile.mktemp()
     command = "apt-cache dumpavail > " + tmpcache
     perform.execute(command)
+    # 090501 Begin
+    command = "cat /var/lib/dpkg/status >> " + tmpcache
+    perform.execute(command)
+    # 090501 End
     avail = apt_pkg.ParseTagFile(file(tmpcache))
     if os.path.exists(tmpcache): os.remove(tmpcache)
     return(avail)
@@ -222,20 +231,22 @@ def do_describe(packages):
             print "="*72
             sys.stdout.flush()
 
-# 090501 The following just does not do anything sensible - remove
-# until figured out!
+    # 090409 Bug #432266 From Reuben Thomas <rrt@sc3d.org> 9 Apr 2009
+    # Call to apt-cache dumpavail fails for packages installed but no
+    # longer available. His original suggestion was to use dpkg
+    # --status.  That did not work! He then supplied this one which
+    # uses grep-status from dctrl package. But this accounts for only
+    # "detail" and not "describe" and "new". So remove for now until
+    # that is fixed.
 
-    # From Reuben Thomas <rrt@sc3d.org> 7 Apr 2009 Call to apt-cache
-    # dumpavail fails, you use dpkg --status instead.
 #    l = package_names[:]
 #    for p in l:
 #        # if perform.execute("dpkg --status %s" % p) == 0:
-#            #print(perform.execute("dpkg-query --show --showformat='${Package}\t${Description}\n' " % p % " | grep -v '^ '"))
-#        if perform.execute("dpkg-query --show --showformat='${Package}\t${Description}\n'  %s | grep -v '^ '" % p) == 0:
-#            print "="*72
+#        if perform.execute("grep-status -PX %s" % p) == 0:
 #            sys.stdout.flush()
 #            package_names.remove(p)
     # End Reuben Thomas patch.
+
     if package_names:
         packages = package_names
     else:
@@ -1336,13 +1347,25 @@ def do_whichpkg(filename):
     print "AVAILABLE"
     results = tempfile.mktemp()
     filename = filename.replace('+', '%2B')
+    
+    # 100117 Bug#565666 Update to newer search syntax. TODO We should
+    # really also determine the version and arch and pop the correct
+    # ones in, rather than hard coding unstable and amd64.
+
+    # command = "wget --timeout=60 --output-document=" + results +\
+    #           " http://" + packages_host + "/cgi-bin" +\
+    #           "/search_contents.pl\?word=" + filename +\
+    #           "\&searchmode=searchfilesanddirs" +\
+    #           "\&case=insensitive\&version=unstable" +\
+    #           "\&arch=i386 2> /dev/null"
 
     command = "wget --timeout=60 --output-document=" + results +\
-              " http://" + packages_host + "/cgi-bin" +\
-              "/search_contents.pl\?word=" + filename +\
-              "\&searchmode=searchfilesanddirs" +\
-              "\&case=insensitive\&version=unstable" +\
-              "\&arch=i386 2> /dev/null"
+              " http://" + packages_host +\
+              "/search\?searchon=contents\&keywords=" + filename +\
+              "\&mode=filename" +\
+              "\&suite=unstable" +\
+              "\&arch=any 2> /dev/null"
+
     perform.execute(command)
     #
     # Test for multiple page output and handle appropriately
@@ -1372,9 +1395,9 @@ def do_whichpkg(filename):
                   "do " +\
                   "wget --timeout=60 --output-document=" + results +\
                   " http://packages.debian.org/cgi-bin" +\
-                  "/search_contents.pl?page=$i\&word=" + filename +\
-                  "\&version=unstable\&arch=i386" +\
-                  "\&case=insensitive\&searchmode=searchfilesanddirs " +\
+                  "/search\?searchon=contents\&page=$i\&keywords=" + filename +\
+                  "\&version=unstable\&arch=amd64" +\
+                  "\&mode=path " +\
                   " 2> /dev/null; " +\
                   "cat " + results + " | " +\
                   "egrep -v " +\
@@ -1391,10 +1414,10 @@ def do_whichpkg(filename):
         command = "cat " + results + " | " +\
                   "awk 'BEGIN { RS = \"</tr>\" } " +\
                   "/\"keyword\"/ { print $0 }' | " +\
-                  "lynx -stdin -dump -nonumbers | " +\
+                  "lynx -stdin -dump -nonumbers -nolist | " +\
                   "egrep -v '^$' | " +\
                   "sed 's|, |,|' | " +\
-                  "awk '{printf(\"%-59s %-17s\\n\", $1, $2)}'"
+                  "awk '{printf(\"%-59s %-17s\\n\", $1, $2\" \"$3\" \"$4)}'"
                   # 071104 gjw HTML FORMAT CHANGED
                   # "egrep -v " +\
                   # "'^ *<|^$|^Packages search page|^package |//W3C//' | " +\
